@@ -63,9 +63,11 @@ static const struct { char *algo; uint64_t cipher; } conv[] = {
 	{"HMAC-SHA2-224", ACVP_HMACSHA2_224},
 	{"HMAC-SHA2-256", ACVP_HMACSHA2_256},
 	{"HMAC-SHA2-384", ACVP_HMACSHA2_384},
-	{"HMAC-SHA2-512", ACVP_HMACSHA2_512},
 	{"HMAC-SHA2-512/224", ACVP_HMACSHA2_512224},
 	{"HMAC-SHA2-512/256", ACVP_HMACSHA2_512256},
+	{"HMAC-SHA2-512\\/224", ACVP_HMACSHA2_512224},
+	{"HMAC-SHA2-512\\/256", ACVP_HMACSHA2_512256},
+	{"HMAC-SHA2-512", ACVP_HMACSHA2_512},
 	{"HMAC-SHA3-224", ACVP_HMACSHA3_224},
 	{"HMAC-SHA3-256", ACVP_HMACSHA3_256},
 	{"HMAC-SHA3-384", ACVP_HMACSHA3_384},
@@ -87,9 +89,11 @@ static const struct { char *algo; uint64_t cipher; } conv[] = {
 	{"SHA2-224", ACVP_SHA224},
 	{"SHA2-256", ACVP_SHA256},
 	{"SHA2-384", ACVP_SHA384},
-	{"SHA2-512", ACVP_SHA512},
 	{"SHA2-512/224", ACVP_SHA512224},
 	{"SHA2-512/256", ACVP_SHA512256},
+	{"SHA2-512\\/224", ACVP_SHA512224},
+	{"SHA2-512\\/256", ACVP_SHA512256},
+	{"SHA2-512", ACVP_SHA512},
 	{"ctrDRBG", ACVP_DRBGCTR},
 	{"hashDRBG", ACVP_DRBGHASH},
 	{"hmacDRBG", ACVP_DRBGHMAC},
