@@ -131,6 +131,11 @@ void ecdsa_get_bufferlen(uint64_t curve, size_t *dlen,
 			 size_t *xlen, size_t *ylen)
 {
 	switch (curve & ACVP_CURVEMASK) {
+		case ACVP_NISTP192:
+			*xlen = 192 / 8;
+			*dlen = *xlen;
+			*ylen = *xlen;
+			break;
 		case ACVP_NISTP224:
 			*xlen = 224 / 8;
 			*dlen = *xlen;
@@ -275,7 +280,7 @@ static int ecdsa_tester(struct json_object *in, struct json_object *out,
 	const struct json_entry ecdsa_siggen_testgroup_entries[] = {
 		{"curve",	{.data.largeint = &ecdsa_siggen_vector.cipher, PARSER_CIPHER},	FLAG_OP_AFT | FLAG_OP_ASYM_TYPE_SIGGEN },
 		{"hashAlg",	{.data.largeint = &ecdsa_siggen_vector.cipher, PARSER_CIPHER},	FLAG_OP_AFT | FLAG_OP_ASYM_TYPE_SIGGEN },
-		{"component",	{.data.integer = &ecdsa_siggen_vector.component, PARSER_BOOL},	FLAG_OP_AFT | FLAG_OP_ASYM_TYPE_SIGGEN | FLAG_OPTIONAL},
+		{"componentTest",	{.data.integer = &ecdsa_siggen_vector.component, PARSER_BOOL},	FLAG_OP_AFT | FLAG_OP_ASYM_TYPE_SIGGEN | FLAG_OPTIONAL},
 		{"tests",	{.data.array = &ecdsa_siggen_test, PARSER_ARRAY},		FLAG_OP_AFT | FLAG_OP_ASYM_TYPE_SIGGEN },
 	};
 	const struct json_array ecdsa_siggen_testgroup = SET_ARRAY(ecdsa_siggen_testgroup_entries,
