@@ -572,7 +572,7 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
 {
 	uint32_t oloop = 0;
 	uint32_t iloop = 0;
-	int ret = 1;
+	int ret = -EINVAL;
 	BUFFER_INIT(calc_data);
 	struct json_object *testresult, *resultsarray = NULL;
 
@@ -611,9 +611,8 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
  			       vector->iv.buf, vector->iv.len);
 		}
 
-		if (!sym_backend->mct_init ||
-		    sym_backend->mct_init(vector, parsed_flags))
-			goto out;
+		CKNULL(sym_backend->mct_init, -EFAULT);
+		CKINT(sym_backend->mct_init(vector, parsed_flags));
 
 		/*
 		 * Create the output JSON stream holding the test
@@ -632,8 +631,7 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
 
 			logger_binary(LOGGER_DEBUG, vector->data.buf,
 				      vector->data.len, "MCT source data");
-			if (sym_backend->mct_update(vector, parsed_flags))
-				goto out;
+			CKINT(sym_backend->mct_update(vector, parsed_flags));
 			logger_binary(LOGGER_DEBUG, vector->data.buf,
 				      vector->data.len, "MCT calculated data");
 
@@ -678,8 +676,7 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
 			       vector->data.len);
 
 		/* final invocation without subsequent shuffling */
-		if (sym_backend->mct_update(vector, parsed_flags))
-			goto out;
+		CKINT(sym_backend->mct_update(vector, parsed_flags));
 
 		/* Enqueue generated byte into calc_data */
 		if (vector->cipher == ACVP_CFB8) {
